==> OpenSceneGraph-3.3.1.zip: OpenSceneGraph-3.3.1/src/osgVolume/Shaders/volume_accumulateSamples_mip_frag.cpp <==
char volume_accumulateSamples_mip_frag[] = "#version 110\n"
                                           "\n"
                                           "uniform sampler3D volumeTexture;\n"
                                           "\n"
                                           "vec4 accumulateSamples(vec3 ts, vec3 te, vec3 dt, float scale, float cutoff, int num_iterations)\n"
                                           "{\n"
                                           "    vec3 texcoord = te.xyz;\n"
                                           "    vec4 fragColor = vec4(0.0, 0.0, 0.0, 0.0);\n"
                                           "\n"
                                           "    while(num_iterations>0)\n"
                                           "    {\n"
                                           "        vec4 color = texture3D( volumeTexture, texcoord);\n"
                                           "\n"
                                           "        if (color.a>fragColor.a)\n"
                                           "        {\n"
                                           "            fragColor = color;\n"
                                           "        }\n"
                                           "\n"
                                           "        texcoord += dt;\n"
                                           "\n"
                                           "        --num_iterations;\n"
                                           "    }\n"
                                           "\n"
                                           "    return fragColor;\n"
                                           "}\n"
                                           "\n";

==> OpenSceneGraph-3.3.2.zip: OpenSceneGraph-3.3.2/src/osgVolume/Shaders/volume_accumulateSamples_mip_frag.cpp <==
char volume_accumulateSamples_mip_frag[] = "#version 110\n"
                                           "\n"
                                           "uniform sampler3D volumeTexture;\n"
                                           "\n"
                                           "vec4 accumulateSamples(vec4 fragColor, vec3 ts, vec3 te, vec3 dt, float scale, float cutoff, int num_iterations)\n"
                                           "{\n"
                                           "    vec3 texcoord = te.xyz;\n"
                                           "\n"
                                           "    while(num_iterations>0)\n"
                                           "    {\n"
                                           "        vec4 color = texture3D( volumeTexture, texcoord);\n"
                                           "\n"
                                           "        if (colorcolor.a>AlphaFuncValue &&  color.a>fragColor.a)\n"
                                           "        {\n"
                                           "            fragColor = color;\n"
                                           "        }\n"
                                           "\n"
                                           "        texcoord += dt;\n"
                                           "\n"
                                           "        --num_iterations;\n"
                                           "    }\n"
                                           "\n"
                                           "    return fragColor;\n"
                                           "}\n"
                                           "\n";
